@@ -11,7 +11,13 @@ from hashlib import md5
 from datetime import datetime
 
 
+class UserError(Exception):
+    ...
+
+
 class msgqywx:
+    url = 'https://qyapi.weixin.qq.com/cgi-bin/gettoken'
+
     def __init__(self, corpid: str, corpsecret: str, agentid: str, touser: str = None):
         """
         发送企业微信应用消息
@@ -24,44 +30,39 @@ class msgqywx:
         self.corpsecret = corpsecret
         self.agentid = agentid
         self.touser = touser
-        self.seckey_md5 = md5((self.corpid + self.corpsecret).encode(encoding='utf-8')).hexdigest()
+        self.secret_key_md5 = md5((self.corpid + self.corpsecret).encode(encoding='utf-8')).hexdigest()
         self.base_config_folder = f"{os.path.expanduser('~')}/.config/msgqywx"
         if not os.path.exists(self.base_config_folder):
             os.makedirs(self.base_config_folder)
-        self.accessconffile = os.path.join(self.base_config_folder, f"{self.seckey_md5}.conf")
+        self.access_conf_file = os.path.join(self.base_config_folder, f"{self.secret_key_md5}.conf")
 
     def access_token_to_jsonfile(self):
-        url = 'https://qyapi.weixin.qq.com/cgi-bin/gettoken'
+
         values = {'corpid': self.corpid,
                   'corpsecret': self.corpsecret,
                   }
-        req = requests.post(url, params=values)
-        if req.status_code == 200:
-            data = json.loads(req.text)
-            wite_json = {"cur_time": datetime.now().timestamp(),
-                         "access_token": data["access_token"]}
-            with open(self.accessconffile, 'w') as f:
-                json.dump(wite_json, f)
-            return wite_json
+        response = requests.post(self.url, params=values)
+        if response.ok:
+            data = json.loads(response.text)
+            secret_json = {"expire_time": datetime.now().timestamp() + 3600,
+                           "access_token": data["access_token"]}
+            with open(self.access_conf_file, 'w') as f:
+                json.dump(secret_json, f)
+            return secret_json
         else:
-            print(req.text)
+            print(response.text)
             raise Exception("获取企业微信的access_token失败,请检查企业ID（corpid）和应用Secret（corpsecret）是否正确")
 
     def get_access_token(self):
-        try:
-            with open(self.accessconffile, 'r') as f:
+        if os.path.exists(self.access_conf_file):
+            with open(self.access_conf_file, 'r') as f:
                 access_json = json.load(f)
-                cur_time = datetime.now().timestamp()
-                if 0 < cur_time - float(access_json["cur_time"]) < 7000:
-                    # print("通过文件获取到access_token")
+                if access_json.get("expire_time", 0) > datetime.now().timestamp():
                     return access_json["access_token"]
                 else:
                     f.close()
                     return self.access_token_to_jsonfile()["access_token"]
-        except FileNotFoundError:
-            return self.access_token_to_jsonfile()["access_token"]
-        except Exception as err:
-            print("未知错误，请告知作者：\n", err)
+        else:
             return self.access_token_to_jsonfile()["access_token"]
 
     def send_msg(self, message, msgtype: str = 'text', touser: str = None, raise_error: bool = False):
@@ -73,31 +74,27 @@ class msgqywx:
         :param touser: 发送用户，和初始化类时的touser不能同时为None
         :return: 微信返回的response，可以自行处理错误信息，也可不处理
         """
+        if msgtype not in ['text', 'markdown']:
+            raise TypeError("Unsupported msgtype, only text and markdown acceptable")
+
         touser = touser if touser else self.touser
         if touser is None:
-            raise Exception("无发送用户")
+            raise UserError("无发送用户")
+
         send_url = 'https://qyapi.weixin.qq.com/cgi-bin/message/send?access_token=' + \
                    self.get_access_token()
         send_values = {
             "touser": touser,
             "agentid": self.agentid,
-            "text": {"content": message},
-            "markdown": {"content": message},
+            "msgtype": msgtype,
+            msgtype: {"content": message}
         }
-        if msgtype == 'text':
-            send_values["msgtype"] = "text"
-            del send_values["markdown"]
-        elif msgtype == 'markdown':
-            send_values["msgtype"] = "markdown"
-            del send_values["text"]
-        else:
-            raise Exception("不支持的msgtype")
 
-        respone = requests.post(send_url, json=send_values)
-        if respone.status_code == 200:
-            return respone
+        response = requests.post(send_url, json=send_values)
+        if response.status_code == 200:
+            return response
         else:
             if raise_error:
-                raise Exception(respone.text)
+                response.raise_for_status()
             else:
-                return respone
+                return response
